#  This file is a part of the LinkAhead Project.
#
#  Copyright (C) 2024 Henrik tom Wörden (h.tomwoerden@indiscale.com)
#  Copyright (C) 2020-2024 IndiScale GmbH (info@indiscale.com)
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program. If not, see <https://www.gnu.org/licenses/>.

from os.path import abspath, dirname, join
from pytest import raises
from linkahead import get_connection, configure_connection
from linkahead.connection.mockup import (MockUpServerConnection, MockUpResponse)
from loan.box_loan import (_caller, create_person,
                         EMAIL, FIRST_NAME, LAST_NAME, PERSON,
                         assert_date_in_future, DataError, EmailPatternError,
                         assert_email_pattern)

from utils import get_form_data_example



def test_return_value_of_caller():
    tval = 1337
    assert _caller(lambda d: tval, [get_form_data_example()]
) == tval

def test_create_person():
    p = create_person("anna", "lytik", "a@b.com")
    assert p.get_parents()[0].name == PERSON.name
    assert p.get_property(FIRST_NAME.name).value == "anna"
    assert p.get_property(LAST_NAME.name).value == "lytik"
    assert p.get_property(EMAIL.name).value == "a@b.com"

def test_email_validation():
    with raises(EmailPatternError):
        assert_email_pattern("@asdf")
    with raises(EmailPatternError):
        assert_email_pattern("asdf")
    with raises(EmailPatternError):
        assert_email_pattern("asdfa.de")
    with raises(EmailPatternError):
        assert_email_pattern("sdfg@sdfg")

    # the following shoudl be ok
    assert_email_pattern("a@b.da")
    assert_email_pattern("\"#\"@ö.de")

def test_assert_date_in_future():
    # I can't wait for 2050 :-)
    assert assert_date_in_future("2050-01-01") is None
    with raises(DataError):
        assert_date_in_future("1971-01-01")
